package virtbuf

// functions to import and export the protobuf
// data to and from config files

import (
	"google.golang.org/protobuf/encoding/protojson"
	"google.golang.org/protobuf/encoding/prototext"
	"google.golang.org/protobuf/proto"
)

// human readable JSON
func (c *Cluster) FormatJSON() string {
	return protojson.Format(c)
}

func (d *Droplets) FormatJSON() string {
	return protojson.Format(d)
}

func (d *Droplet) FormatJSON() string {
	return protojson.Format(d)
}

func (e *Events) FormatJSON() string {
	return protojson.Format(e)
}

func (h *Hypervisors) FormatJSON() string {
	return protojson.Format(h)
}

// apparently this isn't supposed to be used?
// https://protobuf.dev/reference/go/faq/#unstable-text
// this is a shame because this is much nicer output than JSON Format()
func (c *Cluster) FormatTEXT() string {
	return prototext.Format(c)
}

func (d *Droplets) FormatTEXT() string {
	return prototext.Format(d)
}

func (e *Events) FormatTEXT() string {
	return prototext.Format(e)
}

// marshal
func (c *Cluster) MarshalJSON() ([]byte, error) {
	return protojson.Marshal(c)
}

func (d *Droplets) MarshalJSON() ([]byte, error) {
	return protojson.Marshal(d)
}

func (d *Droplet) MarshalJSON() ([]byte, error) {
	return protojson.Marshal(d)
}

func (e *Events) MarshalJSON() ([]byte, error) {
	return protojson.Marshal(e)
}

// unmarshal
func (c *Cluster) UnmarshalJSON(data []byte) error {
	return protojson.Unmarshal(data, c)
}

func (d *Droplets) UnmarshalJSON(data []byte) error {
	return protojson.Unmarshal(data, d)
}

func (d *Droplet) UnmarshalJSON(data []byte) error {
	return protojson.Unmarshal(data, d)
}

func (e *Events) UnmarshalJSON(data []byte) error {
	return protojson.Unmarshal(data, e)
}

func (d *Droplet) Unmarshal(data []byte) error {
	return proto.Unmarshal(data, d)
}
